| api_package | R Documentation |
Packages can included one or more api specification(s) by storing the
annotated route files and/or _server.yml file in subfolders of
./inst/plumber2. The name of the subfolder will be the name of the api
api_package(package = NULL, name = NULL, ...)
package |
The name of the package that provides the api. If |
name |
The name of the api. If |
... |
Arguments passed on to
|
If package or name is NULL then a data frame providing
available apis filtered on either package or name (if any is provided) is
returned. Otherwise a Plumber2 object representing the api is returned
# Load one of the plumber2 examples
api_package("plumber2", "quickstart")
# List all available apis
api_package()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.