View source: R/parse_plumber_file.R
| apply_plumber2_block | R Documentation |
In order to facilitate extensibility of the plumber2 file syntax you can provide your own methods for how to apply information from a plumber2 block to an api.
apply_plumber2_block(block, api, route_name, root, ...)
block |
The block that was parsed |
api |
The Plumber2 api object to apply it to |
route_name |
The name of the route the plumber2 file is associated with.
Either the name of the file or the value of the |
root |
The root given by the potential |
... |
ignored |
api, modified
add_plumber2_tag()
# Add a method for a fictional "hello_block" that makes the api say hello when
# it starts
apply_plumber2_block.hello_block <- function(block, api, route_name, root, ...) {
api$on("start", function(...) {
message("Hello")
})
api
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.