| device_formatter | R Documentation |
This internal function facilitates creating a formatter that uses a specific device for rendering.
device_formatter(dev_open, dev_close = grDevices::dev.off())
dev_open |
The function that opens the device |
dev_close |
The function closing the device. Usually this would be
|
A device formatter function
# Create a png formatter using the default png device
device_formatter(png)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.